==> nextcloud-30.0.12.tgz: nextcloud/apps/federation/l10n/nl.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Toegevoegd aan de lijst met vertrouwde servers",
    "Server is already in the list of trusted servers." : "Server bestaat reeds in de lijst van vertrouwde servers.",
    "No server to federate with found" : "Geen server gevonden om mee te federeren",
    "Could not add server" : "Kon server niet toevoegen",
    "Trusted servers" : "Vertrouwde servers",
    "Federation" : "Federatie",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "Federatie stelt je in staat om verbinding te maken met andere vertrouwde servers om de accountdirectory uit te wisselen. Dit zal bijvoorbeeld worden gebruikt om externe accounts automatisch aan te vullen voor gefedereerd delen.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Federatie stelt je in staat om verbinding te maken met andere vertrouwde servers om de accountdirectory uit te wisselen. Dit zal bijvoorbeeld worden gebruikt om externe accounts automatisch aan te vullen voor gefedereerd delen. Het is niet nodig om een server als vertrouwde server toe te voegen om een gefedereerde share te maken.",
    "+ Add trusted server" : "+ Toevoegen vertrouwde server",
    "Trusted server" : "Vertrouwde server",
    "Add" : "Toevoegen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.12p0.tgz: nextcloud/apps/federation/l10n/nl.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Toegevoegd aan de lijst met vertrouwde servers",
    "No server found with ID: %s" : "Geen server gevonden met ID: %s",
    "Could not remove server" : "Kon server niet verwijderen",
    "Server is already in the list of trusted servers." : "Server bestaat reeds in de lijst van vertrouwde servers.",
    "No server to federate with found" : "Geen server gevonden om mee te federeren",
    "Could not add server" : "Kon server niet toevoegen",
    "Trusted servers" : "Vertrouwde servers",
    "Federation" : "Federatie",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "Met Federatie kun je verbinding maken met andere vertrouwde servers om de accountmap uit te wisselen.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "Federatie stelt je in staat om verbinding te maken met andere vertrouwde servers om de accountdirectory uit te wisselen. Dit zal bijvoorbeeld worden gebruikt om externe accounts automatisch aan te vullen voor gefedereerd delen.",
    "External documentation for Federated Cloud Sharing" : "Externe documentatie voor Federated Cloud Sharing",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Federatie stelt je in staat om verbinding te maken met andere vertrouwde servers om de accountdirectory uit te wisselen. Dit zal bijvoorbeeld worden gebruikt om externe accounts automatisch aan te vullen voor gefedereerd delen. Het is niet nodig om een server als vertrouwde server toe te voegen om een gefedereerde share te maken.",
    "Each server must validate the other. This process may require a few cron cycles." : "Elke server moet de andere valideren. Dit proces kan enkele croncycli duren.",
    "+ Add trusted server" : "+ Toevoegen vertrouwde server",
    "Trusted server" : "Vertrouwde server",
    "Add" : "Toevoegen"
},
"nplurals=2; plural=(n != 1);");
